@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = "1.1.0"
+__version__ = "1.2.0"
 __all__ = [
     "__version__",
     "TemplateLoader",
@@ -26,9 +26,3 @@ __all__ = [
 from piglet.loader import TemplateLoader
 from piglet.template import HTMLTemplate, TextTemplate
 from piglet.exceptions import PigletError, PigletParseError, TemplateNotFound
-
-from parsley import ParseError
-
-# Monkey patch to avoid 'TypeError: unhashable type' internal errors when
-# running under pytest.
-ParseError.__hash__ = Exception.__hash__
