@@ -243,8 +243,7 @@ class Compiler:
                     module="piglet.exceptions",
                     names=[
                         alias(
-                            name="TemplateNotFound",
-                            asname="__piglet_TemplateNotFound",
+                            name="TemplateNotFound", asname="__piglet_TemplateNotFound",
                         )
                     ],
                     level=0,
@@ -631,14 +630,9 @@ class Compiler:
             targets=[Name(id=str(srcnode.alias), ctx=Store())],
             value=Call(
                 func=Attribute(
-                    value=Name(id="__piglet_rt", ctx=Load()),
-                    attr="load",
-                    ctx=Load(),
+                    value=Name(id="__piglet_rt", ctx=Load()), attr="load", ctx=Load(),
                 ),
-                args=[
-                    Name(id="__piglet_template", ctx=Load()),
-                    Str(s=srcnode.href),
-                ],
+                args=[Name(id="__piglet_template", ctx=Load()), Str(s=srcnode.href),],
                 starargs=None,
                 kwargs=None,
                 keywords=[],
@@ -1055,8 +1049,7 @@ def _hoist_variables_to_piglet_context(astnode, exclude_functions=frozenset()):
 
     for ancestors, node in names:
         container_func = next(
-            (a for a in reversed(ancestors) if isinstance(a, FunctionDef)),
-            None,
+            (a for a in reversed(ancestors) if isinstance(a, FunctionDef)), None,
         )
         if container_func in exclude_functions:
             continue
@@ -1096,9 +1089,7 @@ def _hoist_variables_to_piglet_context(astnode, exclude_functions=frozenset()):
 
             value = Call(
                 func=Attribute(
-                    value=Name(id="__piglet_ctx", ctx=Load()),
-                    attr="get",
-                    ctx=Load(),
+                    value=Name(id="__piglet_ctx", ctx=Load()), attr="get", ctx=Load(),
                 ),
                 args=[Str(s=n), default],
                 starargs=None,
