@@ -16,6 +16,7 @@
 Compile XML to an intermediate parse tree
 """
 from copy import copy
+from html import unescape
 from itertools import chain
 from itertools import product
 from itertools import takewhile
@@ -55,40 +56,6 @@ HTML_EMPTY_ATTRS = {
     "selected",
 }
 
-try:
-    from html import unescape
-except ImportError:
-    import htmlentitydefs
-
-    def unescape(text):
-        """
-        Removes HTML or XML character references and entities from a text string.
-
-        @param text The HTML (or XML) source text.
-        @return The plain text, as a Unicode string, if necessary.
-
-        Adapted from http://effbot.org/zone/re-sub.htm#unescape-html
-        """
-
-        def fixup(m):
-            text = m.group(0)
-            if text[:2] == "&#":
-                try:
-                    if text[:3] == "&#x":
-                        return unichr(int(text[3:-1], 16))  # noqa
-                    else:
-                        return unichr(int(text[2:-1]))  # noqa
-                except ValueError:
-                    pass
-            else:
-                try:
-                    text = unichr(htmlentitydefs.name2codepoint[text[1:-1]])  # noqa
-                except KeyError:
-                    pass
-            return text
-
-        return re.sub(r"&#?\w+;", fixup, text)
-
 
 WHITESPACE = "py:whitespace"
 
@@ -306,24 +273,15 @@ directives = [
     Directive(name="for", attr="each", factory=im.ForNode.factory),
     Directive(name="if", attr="test", factory=im.IfNode.factory),
     Directive(
-        name="switch",
-        attr="test",
-        default="True",
-        factory=im.ChooseNode.factory,
+        name="switch", attr="test", default="True", factory=im.ChooseNode.factory,
     ),
     Directive(
-        name="choose",
-        attr="test",
-        default="True",
-        factory=im.ChooseNode.factory,
+        name="choose", attr="test", default="True", factory=im.ChooseNode.factory,
     ),
     Directive(name="call", attr="function", inner=True, factory=im.Call.factory),
     Directive(name="keyword", attr="name", factory=im.CallKeyword.factory),
     Directive(
-        name="content",
-        attr="value",
-        inner=True,
-        factory=im.InterpolateNode.factory,
+        name="content", attr="value", inner=True, factory=im.InterpolateNode.factory,
     ),
     Directive(name="replace", attr="value", factory=im.InterpolateNode.factory),
     Directive(name="filter", attr="function", inner=True, factory=im.FilterNode),
@@ -502,9 +460,9 @@ def make_dom(parse_result):
         elif isinstance(item, parse.CloseTag):
             if item.qname != head.qname:
                 raise parse.PigletParseError(
-                    "Unexpected {} at {}:{}".format(
-                        item.source, item.pos.line, item.pos.char
-                    )
+                    f"Expected </{head.qname}>, got {item.source} "
+                    f"at {item.pos.line}:{item.pos.char}. "
+                    f"Open tags are \"{' > '.join(s.qname for s in stack[1:])}\""
                 )
             head.close_tag = item.source
             head.close_tag_pos = item.pos
@@ -515,10 +473,9 @@ def make_dom(parse_result):
             head.append(item)
     if len(stack) > 1:
         raise parse.PigletParseError(
-            "Missing closing tag for <{}>, "
-            "opened at {}:{}".format(
-                stack[-1].qname, stack[-1].pos.line, stack[-1].pos.char
-            )
+            f"Missing closing tag for <{stack[-1].qname}>, "
+            f"opened at {stack[-1].pos.line}:{stack[-1].pos.char}. "
+            f"Open tags are \"{' > '.join(s.qname for s in stack[1:])}\""
         )
     return stack[0]
 
