@@ -41,8 +41,8 @@ class PigletParseError(PigletError):
     lineno = "(unknown line number)"
     filename = "(unknown filename)"
 
-    def __init__(self, message, filename=None, lineno=None):
-        super(PigletParseError, self).__init__(message)
+    def __init__(self, *args, filename=None, lineno=None):
+        super(PigletParseError, self).__init__(*args)
         self.set_location(filename, lineno)
 
 
