@@ -13,16 +13,10 @@
 # limitations under the License.
 
 from itertools import chain
-from pkg_resources import resource_string
 import re
 
 import attr
-import parsley
-
-
-#: Grammar to parse semicolon separated values in WithNodes
-ssv_grammar = resource_string(__name__, "grammar_ssv.txt").decode("UTF-8")
-ssv_parser = parsley.makeGrammar(ssv_grammar, {})
+from piglet import parsers
 
 
 @attr.s
@@ -287,7 +281,7 @@ class WithNode(DirectiveNode, ContainerNode):
         if isinstance(self.vars, list):
             return self.vars
 
-        values = ssv_parser(self.vars).values()
+        values = parsers.semicolonseparated.ssv_parser.parseString(self.vars)
         values = [tuple(s.strip() for s in str(item).split("=", 1)) for item in values]
         return values
 
