@@ -13,12 +13,12 @@
 # limitations under the License.
 
 from copy import copy
-from pkg_resources import resource_string
 
 import attr
-import parsley
+import pyparsing
 
 from piglet.exceptions import PigletParseError
+from piglet import parsers
 
 
 @attr.s
@@ -34,13 +34,9 @@ class Interpolation(object):
         return ob
 
 
-parser_ns = locals()
-interp_grammar = resource_string(__name__, "grammar_interpolate.txt").decode("UTF-8")
-interp_parser = parsley.makeGrammar(interp_grammar, parser_ns)
-
-
 def parse_interpolations(source):
     try:
-        return interp_parser(source).text_with_interpolations()
-    except parsley.ParseError as e:
-        raise PigletParseError(e.formatError())
+        parse_result = parsers.interpolation_parser.parseString(source)
+    except pyparsing.ParseException as e:
+        raise PigletParseError() from e
+    return list(parse_result)
