@@ -12,12 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from pkg_resources import resource_string
 from collections import OrderedDict
 
 import attr
-import parsley
+import pyparsing
 
+from piglet import parsers
 from piglet.exceptions import PigletParseError
 from piglet.position import Position
 
@@ -74,17 +74,28 @@ class Attribute(ParseItem):
         super(Attribute, self).__init__(*args, **kwargs)
 
     def set_pos(self, pos):
-        self.value_pos = pos.advance(
-            "{0.name}{0.space1}={0.space2}{0.quote}".format(self)
-        )
+        if self.value is not None:
+            self.value_pos = pos.advance(
+                "{0.name}{0.space1}={0.space2}{0.quote}".format(self)
+            )
+        else:
+            self.value_pos = pos.advance(
+                "{0.name}{0.space1}{0.space2}{0.quote}".format(self)
+            )
         return super(Attribute, self).set_pos(pos)
 
     @property
     def source(self):
-        return (
-            "{0.name}{0.space1}="
-            "{0.space2}{0.quote}{0.value}{0.quote}{0.space3}".format(self)
-        )
+        if self.value is not None:
+            return (
+                "{0.name}{0.space1}="
+                "{0.space2}{0.quote}{0.value}{0.quote}{0.space3}".format(self)
+            )
+        else:
+            return (
+                "{0.name}{0.space1}"
+                "{0.space2}{0.space3}".format(self)
+            )
 
 
 @attr.s
@@ -159,23 +170,26 @@ class CDATA(ParseItem):
         return "<![CDATA[{}]]>".format(self.content)
 
 
-parser_ns = locals()
-html_grammar = resource_string(__name__, "grammar.txt").decode("UTF-8")
-html_parser = parsley.makeGrammar(html_grammar, parser_ns)
-
-
 def parse_html(source):
     try:
-        return add_positions(list(flatten(html_parser(source).html())))
-    except parsley.ParseError as e:
-        raise PigletParseError(e.formatError())
+        parse_result = parsers.html_template_parser.parseString(source)
+    except pyparsing.ParseException as e:
+        raise PigletParseError() from e
+    return add_positions(list(flatten(parse_result)))
+
+
+def parse_tt(source):
+    try:
+        parse_result = parsers.text_template_parser.parseString(source)
+    except pyparsing.ParseException as e:
+        raise PigletParseError() from e
+    return add_positions(list(parse_result))
 
 
 def flatten(parse_result):
     for item in parse_result:
         if isinstance(item, list):
-            for i2 in flatten(item):
-                yield i2
+            yield from item
         else:
             yield item
 
