@@ -29,8 +29,8 @@ def update_pos(oldpos, s):
     Update a line, char position as if the cursor has moved through text ``s``.
     """
     l, c = attr.astuple(oldpos)
-    l += s.count('\n')
-    last_newline = s.rfind('\n')
+    l += s.count("\n")
+    last_newline = s.rfind("\n")
     if last_newline < 0:
         c = c + len(s)
     else:
