@@ -92,7 +92,7 @@ def test_it_compiles_choose():
                 ),
                 im.TextNode(pos=P(1, 85), content="<p>some text</p>"),
                 im.OtherwiseNode(
-                    pos=P(1, 101), children=[im.TextNode(pos=P(1, 115), content="zzz")]
+                    pos=P(1, 101), children=[im.TextNode(pos=P(1, 115), content="zzz")],
                 ),
             ],
         )
@@ -257,15 +257,13 @@ def test_it_processes_strip_whitespace():
         im.TextNode(pos=P(1, 1), content="<p><b>\u00a0 foo bar</b></p>"),
     ]
 
-    assert c(
-        '<p py:whitespace="strip"> <b py:whitespace="preserve"> foo </b></p>'
-    ) == [im.TextNode(pos=P(1, 1), content="<p><b> foo </b></p>")]
+    assert c('<p py:whitespace="strip"> <b py:whitespace="preserve"> foo </b></p>') == [
+        im.TextNode(pos=P(1, 1), content="<p><b> foo </b></p>")
+    ]
 
 
 def test_it_processes_strip_whitespace_and_keeps_line_numbering():
-    assert c(
-        '<p py:whitespace="strip"> <py:if test="True"> hello! </py:if></p>'
-    ) == [
+    assert c('<p py:whitespace="strip"> <py:if test="True"> hello! </py:if></p>') == [
         im.TextNode(pos=P(1, 1), content="<p>"),
         im.IfNode(
             pos=P(1, 27),
@@ -317,6 +315,6 @@ def test_it_strips_space_between_py_directives():
 def test_it_preserves_ordering_of_namespaced_attributes():
     assert c('<html lang="en" xml:lang="en"></html>') == [
         im.TextNode(
-            pos=P(line=1, char=1), content='<html lang="en" xml:lang="en"></html>'
+            pos=P(line=1, char=1), content='<html lang="en" xml:lang="en"></html>',
         )
     ]
