@@ -20,14 +20,14 @@ def test_it_parses_text():
 
 
 def test_it_handles_dollars_in_other_contexts():
-    assert parse_interpolations("$11") == ["$", "11"]
-    assert parse_interpolations("1$") == ["1", "$"]
-    assert parse_interpolations("$$$") == ["$", "$"]
-    assert parse_interpolations("$$el") == ["$", "el"]
+    assert parse_interpolations("$11") == ["$11"]
+    assert parse_interpolations("1$") == ["1$"]
+    assert parse_interpolations("$$$") == ["$$"]
+    assert parse_interpolations("$$el") == ["$el"]
 
 
 def test_it_handles_escaped_dollars():
-    assert parse_interpolations("$${") == ["$", "{"]
+    assert parse_interpolations("$${") == ["${"]
 
 
 def test_it_detects_simple_interpolations():
@@ -65,3 +65,15 @@ def test_it_detects_delimited_interpolations():
         Interpolation('${{"foo": "bar"}[item]}', '{"foo": "bar"}[item]'),
         " chips",
     ]
+
+
+def test_it_handles_nested_braces():
+    assert parse_interpolations("${{{}}}") == [
+        Interpolation("${{{}}}", "{{}}")
+    ]
+
+
+def test_it_handles_multiple_braces():
+    assert parse_interpolations("${({}, {})}") == [
+        Interpolation("${({}, {})}", "({}, {})")
+    ]
