@@ -70,6 +70,50 @@ class TestParser:
             CloseTag(P(1, 19), "p"),
         ]
 
+    def test_it_parses_valueless_attributes(self):
+        assert parse_html("<a b></a>") == [
+            OpenTag(
+                P(1, 1),
+                "a",
+                space=" ",
+                attrs={
+                    "b": Attribute(
+                        pos=P(1, 4),
+                        name="b",
+                        value=None,
+                        value_pos=P(1, 5),
+                        quote="",
+                        space1="",
+                        space2="",
+                        space3="",
+                    )
+                },
+            ),
+            CloseTag(P(1, 6), "a"),
+        ]
+
+    def test_it_parses_valueless_unicode_attributes(self):
+        assert parse_html("<html ⚡></html>",) == [
+            OpenTag(
+                P(1, 1),
+                "html",
+                space=" ",
+                attrs={
+                    "⚡": Attribute(
+                        pos=P(1, 7),
+                        name="⚡",
+                        value=None,
+                        value_pos=P(1, 8),
+                        quote="",
+                        space1="",
+                        space2="",
+                        space3="",
+                    )
+                },
+            ),
+            CloseTag(P(1, 9), "html"),
+        ]
+
     def test_it_parses_comment(self):
         assert parse_html("<!-- x -->") == [Comment(P(1, 1), content=" x ")]
 
@@ -82,6 +126,10 @@ class TestParser:
     def test_it_parses_numeric_entity(self):
         assert parse_html("&#160;") == [Entity(P(1, 1), reference="&#160;")]
 
+    def test_it_parses_hex_entity(self):
+        assert parse_html("&#xa0;") == [Entity(P(1, 1), reference="&#xa0;")]
+        assert parse_html("&#xA0;") == [Entity(P(1, 1), reference="&#xA0;")]
+
     def test_it_preserves_whitespace(self):
         assert parse_html('<a\n\thref =  "foo" ></a>') == [
             OpenTag(
