@@ -267,12 +267,7 @@ class TestTemplate:
 
 class TestPyExtends:
     def test_it_extends(self):
-        with create_templates(
-            [
-                ("a", "A"),
-                ("b", 'B<py:extends href="a"/>'),
-            ]
-        ) as d:
+        with create_templates([("a", "A"), ("b", 'B<py:extends href="a"/>'),]) as d:
             loader = TemplateLoader([d])
             assert loader.load("b").render({}) == "BA"
 
