@@ -16,7 +16,7 @@ from piglet.position import Position
 
 
 def test_advance():
-    assert Position(1, 1).advance('') == Position(1, 1)
-    assert Position(1, 1).advance('f') == Position(1, 2)
-    assert Position(1, 3).advance('f\n\na\nccc') == Position(4, 4)
-    assert Position(1, 2).advance('f') == Position(1, 3)
+    assert Position(1, 1).advance("") == Position(1, 1)
+    assert Position(1, 1).advance("f") == Position(1, 2)
+    assert Position(1, 3).advance("f\n\na\nccc") == Position(4, 4)
+    assert Position(1, 2).advance("f") == Position(1, 3)
